@@ -5,7 +5,7 @@
 #
 # Copyright (c) 2007-2008 Peng Huang <shawn.p.huang@gmail.com>
 # Copyright (c) 2009 Hideaki ABE <abe.sendai@gmail.com>
-# Copyright (c) 2007-2010 Red Hat, Inc.
+# Copyright (c) 2007-2011 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -79,7 +79,7 @@ class AnthyPrefs(Prefs):
         return _japanese_ordered_list
 
     def get_version(self):
-        return '1.2.5'
+        return '1.2.6'
 
 # Sad! dict.keys() doesn't return the saved order.
 # locale.strcoll() also just returns the Unicode code point.
@@ -90,17 +90,20 @@ _japanese_ordered_list = [
     "ぁ", "ぃ", "ぅ", "ぇ", "ぉ",
     "いぇ",
     "うぁ", "うぃ", "うぅ", "うぇ", "うぉ",
+    "うゃ", "うゅ", "うょ",
     "か", "き", "く", "け", "こ",
     "ゕ", "ゖ", "ヵ", "ヶ",
     "が", "ぎ", "ぐ", "げ", "ご",
     "きゃ", "きぃ", "きゅ", "きぇ", "きょ",
-    "くぁ",
+    "くぁ", "くぃ", "くぅ", "くぇ", "くぉ",
     "ぎゃ", "ぎぃ", "ぎゅ", "ぎぇ", "ぎょ",
-    "ぐぁ",
+    "ぐぁ", "ぐぃ", "ぐぅ", "ぐぇ", "ぐぉ",
     "さ", "し", "す", "せ", "そ",
     "ざ", "じ", "ず", "ぜ", "ぞ",
     "しゃ", "しぃ", "しゅ", "しぇ", "しょ",
     "じゃ", "じぃ", "じゅ", "じぇ", "じょ",
+    "すぅぃ", "すぇ",
+    "ずぇ",
     "た", "ち", "つ", "て", "と",
     "だ", "ぢ", "づ", "で", "ど",
     "っ",
@@ -108,6 +111,9 @@ _japanese_ordered_list = [
     "ぢぃ", "ぢぇ",
     "ぢゃ", "ぢゅ", "ぢょ",
     "つぁ", "つぃ", "つぇ", "つぉ",
+    "つゃ", "つぃぇ", "つゅ", "つょ",
+    "づぁ", "づぃ", "づぇ", "づぉ",
+    "づゃ", "づぃぇ", "づゅ", "づょ",
     "てぃ", "てぇ",
     "てゃ", "てゅ", "てょ",
     "とぅ",
@@ -128,6 +134,8 @@ _japanese_ordered_list = [
     "ぴゃ", "ぴゅ", "ぴょ",
     "ふぁ", "ふぃ", "ふぇ", "ふぉ",
     "ふゃ", "ふゅ", "ふょ",
+    "ぶぁ", "ぶぇ", "ぶぉ",
+    "ぷぁ", "ぷぇ", "ぷぉ",
     "ま", "み", "む", "め", "も",
     "みぃ", "みぇ",
     "みゃ", "みゅ", "みょ",
@@ -141,6 +149,7 @@ _japanese_ordered_list = [
     "ゐ", "ゑ",
     "ー",
     "ヴぁ", "ヴぃ", "ヴ", "ヴぇ", "ヴぉ",
+    "ヴゃ", "ヴぃぇ", "ヴゅ", "ヴょ",
 ]
 
 _cmd_keys = [
@@ -250,6 +259,13 @@ _config = {
         'newkeys': [],
     },
 
+    ##0 MS-IME
+    # http://www.filibeto.org/sun/lib/solaris10-docs/E19253-01/819-7844/appe-1-4/index.html
+    ##1 ATOK
+    # http://www.filibeto.org/sun/lib/solaris10-docs/E19253-01/819-7844/appe-1-3/index.html
+    ##2 Gairaigo http://ja.wikipedia.org/wiki/%E5%A4%96%E6%9D%A5%E8%AA%9E
+    ##3 ANSI/BSI Suggestions http://en.wikipedia.org/wiki/Katakana
+    # Maybe we need a compatibility between MS-IME and ibus-anthy.
     'romaji_typing_rule/default': {
         "-": "ー",
         "a" : "あ",
@@ -271,11 +287,18 @@ _config = {
         "whi" : "うぃ",
         "whe" : "うぇ",
         "who" : "うぉ",
+        "wya" : "うゃ", ##2
+        "wyu" : "うゅ", ##2
+        "wyo" : "うょ", ##2
         "va" : "ヴぁ",
         "vi" : "ヴぃ",
         "vu" : "ヴ",
         "ve" : "ヴぇ",
         "vo" : "ヴぉ",
+        "vya" : "ヴゃ",   ##2
+        "vyu" : "ヴゅ",   ##2
+        "vye" : "ヴぃぇ", ##2
+        "vyo" : "ヴょ",   ##2
         "ka" : "か",
         "ki" : "き",
         "ku" : "く",
@@ -298,12 +321,20 @@ _config = {
         "kye" : "きぇ",
         "kyo" : "きょ",
         "kwa" : "くぁ",
+        "kwi" : "くぃ", ##2
+        "kwu" : "くぅ", ##2
+        "kwe" : "くぇ", ##2
+        "kwo" : "くぉ", ##2
         "gya" : "ぎゃ",
         "gyi" : "ぎぃ",
         "gyu" : "ぎゅ",
         "gye" : "ぎぇ",
         "gyo" : "ぎょ",
         "gwa" : "ぐぁ",
+        "gwi" : "ぐぃ", ##2
+        "gwu" : "ぐぅ", ##2
+        "gwe" : "ぐぇ", ##2
+        "gwo" : "ぐぉ", ##2
         "sa" : "さ",
         "si" : "し",
         "su" : "す",
@@ -339,6 +370,9 @@ _config = {
         "jye" : "じぇ",
         "jo" : "じょ",
         "jyo" : "じょ",
+        "swi" : "すぅぃ", ##2
+        "swe" : "すぇ",   ##2
+        "zwe" : "ずぇ",   ##2
         "ta" : "た",
         "ti" : "ち",
         "tu" : "つ",
@@ -378,6 +412,18 @@ _config = {
         "tsi" : "つぃ",
         "tse" : "つぇ",
         "tso" : "つぉ",
+        "tsya" : "つゃ",   ##3
+        "tsyu" : "つゅ",   ##3
+        "tsye" : "つぃぇ", ##3
+        "tsyo" : "つょ",   ##3
+        "dza" : "づぁ",    ##3
+        "dzi" : "づぃ",    ##3
+        "dze" : "づぇ",    ##3
+        "dzo" : "づぉ",    ##3
+        "dzya" : "づゃ",   ##3
+        "dzyu" : "づゅ",   ##3
+        "dzye" : "づぃぇ", ##3
+        "dzyo" : "づょ",   ##3
         "tha" : "てゃ",
         "thi" : "てぃ",
         "thu" : "てゅ",
@@ -440,6 +486,12 @@ _config = {
         "fyu" : "ふゅ",
         "fye" : "ふぇ",
         "fyo" : "ふょ",
+        "bwa" : "ぶぁ", ##2
+        "bwe" : "ぶぇ", ##2
+        "bwo" : "ぶぉ", ##2
+        "pwa" : "ぷぁ", ##2
+        "pwe" : "ぷぇ", ##2
+        "pwo" : "ぷぉ", ##2
         "ma" : "ま",
         "mi" : "み",
         "mu" : "む",
@@ -765,9 +817,11 @@ _config = {
     'dict': {
         'anthy_zipcode': ['/usr/local/share/anthy/zipcode.t'],
         'ibus_symbol': ['/usr/local/share/ibus-anthy/dicts/symbol.t'],
+        'ibus_oldchar': ['/usr/local/share/ibus-anthy/dicts/oldchar.t'],
         'files': [
             '/usr/local/share/anthy/zipcode.t',
             '/usr/local/share/ibus-anthy/dicts/symbol.t',
+            '/usr/local/share/ibus-anthy/dicts/oldchar.t',
         ],
     },
 
@@ -816,6 +870,17 @@ _config = {
         'reverse': False,
         'is_system': True,
     },
+
+    'dict/file/ibus_oldchar': {
+        'embed': False,
+        'single': True,
+        'icon': None,
+        'short_label': '旧',
+        'long_label': N_("Old Character Style"),
+        'preview_lines': -1,
+        'reverse': False,
+        'is_system': True,
+    },
 }
 
 _shortcut_default = {
